"""GWAPI Exceptions"""
from .utils import is_json


class GwapiException(Exception):
    """
    A base class from which all other exceptions inherit.
    If you want to catch all errors that the GWAPI package might raise,
    catch this base exception.
    """


class InvalidVersion(GwapiException):
    pass


class AuthenticationError(GwapiException):
    pass


class ApiError(GwapiException):
    """Handle API error."""
    def __init__(self, message, text, status_code, reason):
        self.message = message
        self.text = text
        self.status_code = status_code
        self.reason = reason

    def __str__(self):
        if is_json(self.text):
            return "{}: {} {} {}".format(self.message, self.status_code, self.reason, self.text)
        else:
            return "{}: {} {}".format(self.message, self.status_code, self.reason)