"""GWAPI utils."""
import json
from packaging import version


def is_int(string: str) -> bool:
    try:
        int(string)
        return True
    except ValueError:
        return False


def is_json(string: str) -> bool:
    try:
        json.loads(string)
    except ValueError:
        return False
    return True


def compare_version(v1: str, v2: str) -> int:
    """Compare Gcenter versions
    >>> v1 = '2.5.3.101'
    >>> v2 = '2.5.3.102'
    >>> compare_version(v1, v2)
    1
    >>> compare_version(v2, v1)
    -1
    >>> compare_version(v2, v2)
    0
    """
    s1 = version.parse(v1)
    s2 = version.parse(v2)
    if s1 == s2:
        return 0
    elif s1 > s2:
        return -1
    else:
        return 1


def version_lt(v1: str, v2: str) -> bool:
    return compare_version(v1, v2) > 0


def version_gte(v1: str, v2: str) -> bool:
    return not version_lt(v1, v2)